<!--
https://pypi.org/project/readme-generator/
-->

[![](https://img.shields.io/pypi/pyversions/travis-cron.svg?longCache=True)](https://pypi.org/project/travis-cron/)

#### Installation
```bash
$ [sudo] pip install travis-cron
```

#### CLI
usage|`__doc__`
-|-
`python -m travis_cron.add repo [branch] [interval] [always]` |add travis cron
`python -m travis_cron.clear repo` |clear all travis cron jobs
`python -m travis_cron.crons repo` |print travis crons
`python -m travis_cron.delete repo cron_id ...` |delete travis crons by id

#### Related projects
+   [`travis-generator` - `.travis.yml` generator](https://pypi.org/project/travis-generator/)
+   [`travis-cron` - manage travis cron](https://pypi.org/project/travis-cron/)
+   [`travis-env` - manage travis environment variables](https://pypi.org/project/travis-env/)
+   [`travis-exec` - execute command for all travis repos](https://pypi.org/project/travis-exec/)

<p align="center">
    <a href="https://pypi.org/project/readme-generator/">readme-generator</a>
</p>